@@ -1,14 +1,11 @@
 import asyncio
 import functools
 from functools import reduce
-
-from networktools.colorprint import gprint, bprint, rprint
-
 from .taskloop import coromask, renew, simple_fargs, simple_fargs_out
 from .scheduler import TaskScheduler
 from .taskloop import TaskLoop
-from rich import print
-from networktools.time import timestamp, now
+from .tools import timestamp, now
+
 
 def get_free_ico(icos):
     ico_list = [key for key, v in icos.items() if not v]
@@ -68,16 +65,14 @@ class TaskAssignator:
             tasks = []
             W = 0
             if not queue_tasks.empty():
-                print(now(), queue_tasks)
                 for i in range(queue_tasks.qsize()):
                     # receive ids code
                     ids = queue_tasks.get()
                     code = scheduler.stations.get(ids).get(
-                            self.code_filter)
+                        self.code_filter)
                     scheduler.status_tasks[ids] = True
                     scheduler.sta_init[ids] = True
                     ipt, available = scheduler.pick_one()
-                    print(now(), ipt, available)
                     if available:
                         respuesta = {
                             'station': ids,
@@ -98,12 +93,10 @@ class TaskAssignator:
                                 element = scheduler.stations.get(
                                     ids).get(self.code_filter)
                                 msg = "Adding new station to sta" +\
-                                f"assigned ipt {ipt} -> ico {ico} ->"+\
-                                f"ids {ids}"
+                                    f"assigned ipt {ipt} -> ico {ico} ->" +\
+                                    f"ids {ids}"
                                 level = 20
-                                scheduler.queue_log.put(("Assignator",
-                                                         msg, level, {}))
-
+                                await scheduler.send_log("Assignator", level, msg, [])
                                 dt_group.remove(element)
 
                         elif dt_status == 'ALL':
@@ -115,13 +108,10 @@ class TaskAssignator:
                             assigned_ids.add(ids)
                             self.locker.acquire()
                             msg = "Adding new station to sta" +\
-                            f"assigned ipt {ipt} -> ico {ico} ->"+\
-                            f"ids {ids}"
+                                f"assigned ipt {ipt} -> ico {ico} ->" +\
+                                f"ids {ids}"
                             level = 20
-                            scheduler.queue_log.put(("Assignator",
-                                                     msg, level, {}))
-
-                            print(self.scheduler.assigned_tasks)
+                            await scheduler.send_log("Assignator", level, msg, [])
                             self.scheduler.add_sta_assigned(
                                 ipt, ico, ids)
                             self.locker.release()
@@ -129,18 +119,18 @@ class TaskAssignator:
                                               True})
                         self.queue_ans.put(respuesta)
                     else:
-                        msg = f"All slots are "+\
+                        msg = f"All slots are " +\
                               f"used, can't add the station {code} ids {ids}"
-                        level = 30 #warning
-                        scheduler.queue_log.put(("Assignator", msg,
-                                                 level, {}))
+
+                        await scheduler.send_log("Assignator", level, msg, [])
+
                 queue_tasks.task_done()
             else:
                 pass
                 # self.queue_ans.put({'added': False})
             return [queue_tasks, *args], kwargs
         except Exception as ex:
-            bprint("Error en asignación de tareas a procesador: %s" % ex)
+            print("Error en asignación de tareas a procesador: %s" % ex)
             raise ex
 
     def new_process_task(self):
@@ -158,5 +148,5 @@ class TaskAssignator:
             if not loop.is_running():
                 loop.run_forever()
         except Exception as ex:
-            rprint("Error en levantar corrutina %s" % ex)
+            print("Error en levantar corrutina %s" % ex)
             raise ex
