@@ -2,13 +2,36 @@
 import asyncio
 from functools import reduce
 # contrib
-from networktools.library import my_random_string
-from networktools.colorprint import gprint, bprint, rprint
-
-from networktools.time import timestamp, now
+from .tools import timestamp, now
 # same module
 from .taskloop import TaskLoop
-from rich import print
+import random
+
+
+def random_char():
+    """
+    Alphabetic uppercase and number 0 to 9 on a random
+    selection
+    """
+    nums = list(range(48, 58))
+    alfab = list(range(65, 91))
+    chars = nums + alfab
+    char_num = random.choice(chars)
+    return chr(char_num)
+
+
+def my_random_string(string_length: int = 10) -> str:
+    """Returns a random string of length string_length.
+
+    :param string_length: a positive int value to define the random length
+    :return:
+    """
+    base = 3
+    assert string_length >= base, "No es un valor positivo sobre " + str(base)
+    rand_list = [random_char() for i in range(string_length)]
+    randstr = "".join(rand_list)
+    return randstr
+
 
 class TaskScheduler:
     """
@@ -224,7 +247,7 @@ class TaskScheduler:
     def get_ipt(self, ids):
         for ipt, ico_set in self.assigned_tasks.items():
             icos = [ico for ico in ico_set if ico_set[ico] == ids]
-            rprint(icos)
+            print(icos)
             if icos:
                 return ipt
         return None
@@ -288,7 +311,6 @@ class TaskScheduler:
         ico_d[ico] = None
         self.assigned_tasks[ipt] = ico_d
 
-
     # @property
     # def ()
 
@@ -305,15 +327,16 @@ class TaskScheduler:
 
     @property
     def assigned_ids(self):
-        assigned_tasks  = set()      # 
+        assigned_tasks = set()      #
         if self.assigned_tasks:
             assigned_tasks = reduce(
-                lambda a,b: a|b, 
+                lambda a, b: a | b,
                 [set(ids_set.values()) for ipt, ids_set in
                  self.assigned_tasks.items()])
 
-        codes = [self.stations.get(ids, {}).get("code") for ids in assigned_tasks]
-        assigned_ids = set(filter(lambda e:e, codes))
+        codes = [self.stations.get(ids, {}).get("code")
+                 for ids in assigned_tasks]
+        assigned_ids = set(filter(lambda e: e, codes))
         return assigned_ids
 
     @property
@@ -323,9 +346,9 @@ class TaskScheduler:
             assigned_tasks = {t for t, v in tasks.items()
                               if v}
             if len(assigned_tasks) == self.lnproc:
-                available[ipt] = False 
+                available[ipt] = False
             else:
-                available[ipt] = True 
+                available[ipt] = True
         return available
 
     def pick_one(self):
@@ -430,7 +453,7 @@ class TaskScheduler:
             )
             tasks.append(task_4)
             for task in tasks:
-                bprint(f"Iniciando tarea->{task}")
+                print(f"Iniciando tarea->{task}")
                 task.create()
         except Exception as exe:
             print("Error en collect_task, manager %s, error %s" % (ipt, exe))
