@@ -1,21 +1,26 @@
+from enum import IntEnum
+from typing import (
+    List,
+    Text,
+    Tuple,
+    Dict,
+    Any,
+    Callable,
+    Coroutine)
 import asyncio
 import functools
 import sys
-from networktools.colorprint import gprint, bprint, rprint
+from dataclasses import dataclass, field
 
 VERSION = sys.version_info
 
 # every coroutine
+
+
 async def pause(sleep, *args, **kwargs):
     await asyncio.sleep(sleep)
     return [sleep, *args], kwargs
 
-from typing import (
-    List,
-    Tuple,
-    Dict,
-    Any,
-    Callable)
 
 # from collections.abc import (Coroutine, Awaitable, Callable)
 # from mypy_extensions import Expand
@@ -30,6 +35,7 @@ from typing import (
 # CoroutineFunctionInput = Callable[[Expand[ArgsInput],
 #                                    Expand[KwargsInput]], ]]
 
+
 async def coromask(
         coro,
         args,
@@ -46,14 +52,13 @@ async def coromask(
 
     :returns: a result, is a list of the elements for future argument
     """
+    msg = ""
     try:
         _in = args
         msg = f"Coromask args {args}, kwargs {kwargs}, in coro {coro}"
         obtained = await coro(*args, **kwargs)
         result = fargs(_in, obtained)
         return result
-    except Exception:
-        raise Exception(msg)
     except asyncio.TimeoutError as te:
         raise te
     except asyncio.CancelledError as ce:
@@ -85,11 +90,9 @@ def renew(task, coro, fargs, *args, **kwargs):
                 return "STOPPED"
         except asyncio.InvalidStateError as ie:
             msg = f"Coro {coro} args {args} kargs {kwargs}"
-            print(msg, ie)
             raise ie
         except Exception as e:
-            msg = f"Resultado  cancelled {task.cancelled()}, {task}, coro {coro}, fargs {fargs}" 
-            print(msg, e)
+            msg = f"Resultado  cancelled {task.cancelled()}, {task}, coro {coro}, fargs {fargs}"
             raise e
     else:
         try:
@@ -128,7 +131,6 @@ def simple_fargs_out(_in, obtained):
     """
     return obtained
 
-from enum import IntEnum
 
 class Steps(IntEnum):
     START = 0
@@ -137,6 +139,7 @@ class Steps(IntEnum):
     STOP = 3
     CANCEL = 4
 
+
 class TaskLoop:
     """
     Esta clase encapsula corrutinas que serán definidas
@@ -165,21 +168,30 @@ class TaskLoop:
     - time_pause :: cantidad de tiempo en pause por cada iteración de loop
 
     """
-    control_words = {"START", "PAUSE", "CONTINUE", "STOP"}
-    _name = "taskloop"
 
-    def __init__(self, coro, coro_args=[], coro_kwargs={}, *args, **kwargs):
-        self.control = 'START'
+    def __init__(
+            self,
+            coro: Coroutine,
+            coro_args: List[Any] = [],
+            coro_kwargs: Dict[str, Any] = {},
+            control: Steps = Steps.START,
+            fargs: Callable = simple_fargs_out,
+            loop: asyncio.AbstractEventLoop = asyncio.get_event_loop(),
+            name: str = "taskloop",
+            time_pause: float = 0.1):
         self.coro = coro
         self.coro_args = coro_args
         self.coro_kwargs = coro_kwargs
+        self.control = control
+        self.fargs = fargs
+        self.loop = loop
+        self._name = name
+        self.time_pause = time_pause
         self.coro_kwargs['taskloop'] = self
-        self._name = kwargs.get('name', 'taskloop')
-        self.fargs = kwargs.get('fargs', simple_fargs_out)
-        self.loop = kwargs.get('loop', asyncio.get_event_loop())
-        asyncio.set_event_loop(self.loop)
-        self.time_pause = kwargs.get('time_pause', .1)
-        self.control = Steps.START
+
+    @property
+    def name(self) -> str:
+        return self._name
 
     def __str__(self):
         return f'''Taskloop {self.name}, coro {self.coro}'''
@@ -197,6 +209,7 @@ class TaskLoop:
         self.control = Steps.CONTINUE
 
     def cancel(self):
+        self.control = Steps.STOP
         return self.active_task.cancel()
 
     def finish(self):
@@ -206,7 +219,7 @@ class TaskLoop:
         try:
             return self.active_task.result()
         except asyncio.CancelledError as ce:
-            raise ce 
+            raise ce
         except asyncio.InvalidStateError as ie:
             raise ie
 
@@ -231,7 +244,7 @@ class TaskLoop:
                     self.coro_kwargs,
                     self.fargs))
             self.done_callback = functools.partial(
-                self.renew, task, 
+                self.renew, task,
                 self.coro,
                 self.fargs)
             task.add_done_callback(self.done_callback)
@@ -246,14 +259,13 @@ class TaskLoop:
                     self.fargs))
 
             self.done_callback = functools.partial(
-                self.renew, task, 
+                self.renew, task,
                 self.coro,
                 self.fargs)
             task.add_done_callback(self.done_callback)
             self.active_task = task
             return task
 
-
     def renew(self, task, coro, fargs, *args, **kwargs):
         """
         A simple function who manages the scheduled task and set the
@@ -314,7 +326,7 @@ class TaskLoop:
                     self.active_task = task
 
             except asyncio.CancelledError as ce:
-                rprint(f"Error de cancelación fargs {fargs}")
+                print(f"Error de cancelación fargs {fargs}")
                 raise ce
             except asyncio.IncompleteReadError as incomplete_read:
                 print("IncompleteReadError {incomplete_read}")
@@ -340,7 +352,8 @@ class TaskLoop:
                     log.exception(msg)
                 raise e
         else:
-            try:
-                exception = task.exception()
-            except Exception as e:
-                raise e
+            # task is cancelled
+            self.control = Steps.STOP
+            task.remove_done_callback(self.done_callback)
+            self.active_task = task
+            return "STOPPED"
